==> v2.22.zip: wcs/wcs/ctl/rebuild_indexes.py <==
# w.c.s. - web application for online forms
# Copyright (C) 2005-2010  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import os

from qommon.ctl import Command, make_option

def rebuild_vhost_indexes(destroy=False):
    from wcs.formdef import FormDef
    if destroy:
        FormDef.destroy_indexes()
    FormDef.rebuild_indexes()
    from wcs.users import User
    if destroy:
        User.destroy_indexes()
    User.rebuild_indexes()
    for formdef in FormDef.select():
        formdata = formdef.data_class()
        if destroy:
            formdata.destroy_indexes()
        formdata.rebuild_indexes()


class CmdRebuildIndexes(Command):
    name = 'rebuild_indexes'

    def __init__(self):
        Command.__init__(self, [
                make_option('--all', action='store_true',
                            dest='all', default=False),
                make_option('--destroy', action='store_true',
                            dest='destroy', default=False),
                ])

    def execute(self, base_options, sub_options, args):
        import publisher

        publisher.WcsPublisher.configure(self.config)
        pub = publisher.WcsPublisher.create_publisher(
                register_tld_names=False)

        app_dir = pub.app_dir
        if sub_options.all:
            hostnames = publisher.WcsPublisher.get_tenants()
        else:
            hostnames = args
        for hostname in hostnames:
            pub.app_dir = os.path.join(app_dir, hostname)
            rebuild_vhost_indexes(destroy=sub_options.destroy)

CmdRebuildIndexes.register()

==> v3.48.zip: wcs/wcs/ctl/rebuild_indexes.py <==
# w.c.s. - web application for online forms
# Copyright (C) 2005-2010  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import os

from qommon.ctl import Command, make_option

def rebuild_vhost_indexes(pub, destroy=False):
    from wcs.formdef import FormDef
    if destroy:
        FormDef.destroy_indexes()
    FormDef.rebuild_indexes()
    from wcs.roles import Role
    if destroy:
        Role.destroy_indexes()
    Role.rebuild_indexes()
    if pub.is_using_postgresql():
        return
    from wcs.users import User
    if destroy:
        User.destroy_indexes()
    User.rebuild_indexes()
    for formdef in FormDef.select():
        formdata = formdef.data_class()
        if destroy:
            formdata.destroy_indexes()
        formdata.rebuild_indexes()


class CmdRebuildIndexes(Command):
    name = 'rebuild_indexes'

    def __init__(self):
        Command.__init__(self, [
                make_option('--all', action='store_true',
                            dest='all', default=False),
                make_option('--destroy', action='store_true',
                            dest='destroy', default=False),
                ])

    def execute(self, base_options, sub_options, args):
        import publisher

        publisher.WcsPublisher.configure(self.config)
        pub = publisher.WcsPublisher.create_publisher(
                register_tld_names=False)

        app_dir = pub.app_dir
        if sub_options.all:
            hostnames = publisher.WcsPublisher.get_tenants()
        else:
            hostnames = args
        for hostname in hostnames:
            pub.app_dir = os.path.join(app_dir, hostname)
            pub.set_config()
            rebuild_vhost_indexes(pub, destroy=sub_options.destroy)

CmdRebuildIndexes.register()
